summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_holder.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_holder.h')
-rw-r--r--kig/objects/object_holder.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kig/objects/object_holder.h b/kig/objects/object_holder.h
index 0afd3892..1d96e007 100644
--- a/kig/objects/object_holder.h
+++ b/kig/objects/object_holder.h
@@ -101,9 +101,9 @@ public:
*/
void draw( KigPainter& p, bool selected ) const;
/**
* Returns whether this object contains the point \p p .
*/
- bool contains( const Coordinate& p, const KigWidget& w, bool nv = false ) const;
+ bool tqcontains( const Coordinate& p, const KigWidget& w, bool nv = false ) const;
/**
* Returns whether this object is in the rectangle \p r .
*/
@@ -101,9 +101,9 @@ public:
void draw( KigPainter& p, bool selected ) const;
/**
- * Returns whether this object contains the point \p p .
+ * Returns whether this object tqcontains the point \p p .
*/